@@ -7,7 +7,7 @@ use feature ':5.10';
 use Carp;
 our @CARP_NOT = qw( Sub::Throttler );
 
-use version; our $VERSION = qv('0.2.0');    # REMINDER: update Changes
+use version; our $VERSION = qv('0.2.1');    # REMINDER: update Changes
 
 # REMINDER: update dependencies in Build.PL
 use Scalar::Util qw( blessed );
@@ -106,7 +106,7 @@ Sub::Throttler::algo - base class for throttling algorithms
 
 This is a base class useful for implementing throttling algorithm plugins
 for L<Sub::Throttler>. For more details check
-L<Sub::Throttler::Limit/"Implementing throttle algorithms/plugins">.
+L<Sub::Throttler/"Implementing throttle algorithms/plugins">.
 
 
 =head1 EXPORTS
@@ -116,6 +116,14 @@ Nothing.
 
 =head1 INTERFACE
 
+=head2 Management of throttle object
+
+All methods listed in this section isn't implemented in
+L<Sub::Throttler::algo>, but they usually should be provided by algorithm
+module inherited from this base class. They isn't required by throttling
+engine so your algorithm may choose to not implement them, but they
+usually needed for user so it's good idea to provide them.
+
 =over
 
 =item new
@@ -125,7 +133,7 @@ Nothing.
 Create and return new instance of this algorithm.
 
 Supported params depends on concrete algorithm, for example see
-L<Sub::Throttler::Limit/"new">, L<Sub::Throttler::Periodic/"new">.
+L<Sub::Throttler::Limit/"new">, L<Sub::Throttler::Periodic::EV/"new">.
 
 It won't affect throttling of your functions/methods until you'll call
 L</"apply_to_functions"> or L</"apply_to_methods"> or L</"apply_to"> or
@@ -169,6 +177,8 @@ every few seconds/minutes).
 
 =head2 Activate throttle for selected subrouties
 
+Methods listed in this section are implemented in L<Sub::Throttler::algo>.
+
 =over
 
 =item apply_to_functions
@@ -334,7 +344,7 @@ Alex Efros  C<< <powerman@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2014 Alex Efros <powerman@cpan.org>.
+Copyright 2014-2015 Alex Efros <powerman@cpan.org>.
 
 This program is distributed under the MIT (X11) License:
 L<http://www.opensource.org/licenses/mit-license.php>
